# Reference

::: playa

::: playa.document
    options:
        members:
        - Document
        - PageList

::: playa.page
    options:
        filters:
        - '!Interpreter'
        - '!Parser'
        inherited_members: true

::: playa.structtree
    options:
        members:
        - StructElement
        - StructTree
        inherited_members: true

::: playa.worker
